#
# spec file for package mstflint
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define extra_version -2

Name:           mstflint
Version:        4.8.0
Release:        lp150.1.8
Summary:        Mellanox Firmware Burning and Diagnostics Tools
License:        GPL-2.0 or BSD-2-Clause
Group:          System/Console
Url:            http://www.openfabrics.org
Obsoletes:      mstflint-devel < %{version}
Source:         https://github.com/Mellanox/mstflint/files/1457191/mstflint-%{version}.tar.gz
# PATCH-FIX-UPSTREAM Build libmtcr as shared library
Source1:        mstfint-mtcr_ul_no_static_lib.patch
# PATCH-FIX-UPSTREAM Add all needed defines to get it built on s390x
Patch1:         mstflint-s390_arch.patch
# PATCH-FIX-UPSTREAM implicit declaration of mset_cr_access
Patch2:         mstflint-4.4.0-implicit-declaration.patch
# PATCH-FIX-UPSTREAM no __DATE__ and __TIME__ in codes
Patch3:         mstflint-4.4.0-no-date-time.patch
# PATCH-FIX-UPSTREAM Add all needed defines to get it built on armv7
Patch4:         mstflint-armv7_arch.patch
# PATCH-FIX-UPSTREAM Ignore fallthrough for GCC7 support
Patch5:         mstflint-gcc7.patch

BuildRequires:  gcc-c++
BuildRequires:  infiniband-diags-devel
BuildRequires:  libtool
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#%%define DT_FLAGS %%{?__commit_date:-D__DATE__=%%__commit_date}' '%%{?__commit_time:-D__TIME__=%%__commit_time}'

%description
This package contains a burning tool and diagnostic tools for Mellanox
manufactured HCA/NIC cards. It also provides access to the relevant
source code. Please see the file LICENSE for licensing details.

This package is based on a subset of the Mellanox Firmware Tools (MFT)
package. For a full documentation of the MFT package, please refer to
the downloads page at the Mellanox web site.

%prep
%setup -q
%patch1
%patch2
%patch3
%patch4
%patch5

%build
./autogen.sh
%configure
make %{?_smp_mflags} CFLAGS="%{optflags} -I. -fno-exceptions"

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
rm -rf %{buildroot}%{_includedir}/mstflint
rm -rf  %{buildroot}%{_libdir}/mstflint/
rm -rf %{buildroot}%{_bindir}/hca_self_test.ofed

%files
%defattr(-, root, root)
%doc README COPYING LICENSE
%{_bindir}/mstconfig
%{_bindir}/mstflint
%{_bindir}/mstfwreset
%{_bindir}/mstmcra
%{_bindir}/mstmread
%{_bindir}/mstmtserver
%{_bindir}/mstmwrite
%{_bindir}/mstregdump
%{_bindir}/mstvpd
%{_mandir}/man1/*.1%{ext_man}
%{_datadir}/mstflint/

%changelog
* Thu Nov  9 2017 nmoreychaisemartin@suse.com
- Update to v4.8.0-2
  * Drop proprietary Mellanox file
* Tue Oct 31 2017 nmoreychaisemartin@suse.com
- Update to v4.8.0-1, No info of changes available (bsc#1046293, fate#322949)
- Update mstflint-gcc7.patch to the latest sources
* Wed Aug  9 2017 nmoreychaisemartin@suse.com
- Update to v4.7.0-1, No info of changes available
* Fri Jun 23 2017 nmoreychaisemartin@suse.com
- Replace dependency from libibmad-devel to infiniband-diags-devel
* Tue May 30 2017 nmoreychaisemartin@suse.com
- Add mstflint-gcc7.patch for GCC7 support
* Thu May 18 2017 nmoreychaisemartin@suse.com
- Add mstflint-armv7_arch.patch to support build on armv7l
- Adapt mstflint-s390_arch.patch to work with s390 and s390x
* Fri Mar 31 2017 nmoreychaisemartin@suse.com
- Update to v4.6.0-1, No info of changes available (fate#321683).
- Adapt patches to changed sources.
- Support build outside of SCM.
* Mon Mar 20 2017 pth@suse.de
- Update to 4.5.0-1.17.g8a0c39d, No info of changes available
  (fate#321683).
- Adapt mstflint-s390_arch.patch to changed sources.
- Remove mstflint-4.4.0-gcc6.patch as it isn't needed anymore.
* Wed Jun 29 2016 i@marguerite.su
- update version 4.4.0
- drop patch: mstflint-autotools.patch, not needed
- drop patch: mstflint-no_Werror.patch, not needed
- add patch: mstflint-4.4.0-gcc6.patch
  * fix boo#985145
  * fix unable to find string literal operator
- add patch: mstflint-4.4.0-implicit-declaration.patch
  * fix implicit declaration of mset_cr_access
  * neither mset_cr_access or MST_MLNXOS exists
- add patch: mstflint-4.4.0-no-date-time.patch
  * fix file-contains-date-and-time
* Mon Feb 22 2016 pth@suse.de
- Add mstflint-common_int_handling.patch to fix integer types handling
  and use common code instead of duplication. This creates two new
  headers, int_handling.h and tools_arch.h. The former has the type
  and print formatting code common to all files.
- Use date and time of .changes file to avoid useless rebuilds.
* Thu Feb 18 2016 pth@suse.de
- Update to 4.3.0 git 9b9af70 (fate#320235 bsc#66196).
- Remove mstflint-autotools.patch as it's not needed anymore.
- Generate ChangeLog from git log and include it.
- Refresh and fix mstflint-s390_arch.patch to apply cleanly.
- Build with Checksums enabled.
- Add placeholder man pages from Debian.
* Sun Mar  8 2015 p.drouand@gmail.com
- Update to version 4.0.0
  * No changelog available
- Use download Url as source
- Update mstflint-autotools.patch
* Fri Aug  8 2014 pth@suse.de
- Rename mstfint-mtcr_ul_no_static_lib to mstfint-mtcr_ul_no_static_lib.patch
  and include the patch for building and using a dynamic library
  as a source.
* Thu Jul 24 2014 pth@suse.de
- Don't install header and library and thus the devel package can
  be removed.
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Fri May 16 2014 pth@suse.de
- Fix mstflint-s390_arch.patch to cover all new cases where
  architecture is checked.
- Add mstflint-no_Werror.patch because currently there are
  warnings where printf formats don't match passed vars.
* Wed May 14 2014 pth@suse.de
- Update to 3.6.0 from OFED 3.12 RC2.
- Remove patches as the code was fixed upstream:
  mstflint-fix_type-punning.patch
  aarch64-arch-detection.diff
- Adapt mstflint-s390_arch.patch to the new code.
- Remove mstflint-shared_lib.patch as it causes more work with
  few gains.
* Tue Apr 22 2014 pth@suse.de
- Add all defines needed for s390.
* Tue Mar  4 2014 pth@suse.de
- Fix mstflint-s390_arch.patch so that it applies.
* Mon Mar  3 2014 pth@suse.de
- Add all necessary defines or s390x (mstflint-s390_arch.patch).
* Mon Feb 10 2014 dmueller@suse.com
- add aarch64-arch-detection.diff: Fix aarch64 detection
* Mon Feb  3 2014 pth@suse.de
- Update to latest 3.5.0. No change log in package.
- Specify full source URL.
- Use spdx.org format for license specification
- Add mstflint-autotools.patch that modifies configure.ac so
  that autoreconf can run successfully.
- Remove configure.in as configure.ac is present.
- Create devel subpackage.
- Add mstflint-fix_type-punning.patch that fixes all cases of
  type-punning by using memcpy.
- Add COPYING and LICENSE to documentation.
* Fri Dec  7 2012 pth@suse.de
- Update to from OFED 1.5.4.1 (fate#314255)
- Remove patches that were integrated:
  mstflint-includefix.patch
  mstflint-1.4-0.6.g63179f4-connectX3.diff
* Tue Jan 10 2012 stefan.fent@suse.com
- Add Connect X3 support (bnc #732326)
* Thu Oct 28 2010 jjolly@novell.com
- Update to v1.4--0.6.g63179f4 from OFED 1.5.2
- Refreshed include error patch
* Thu Dec 11 2008 jjolly@suse.de
- Updated to package from OFED 1.4 GA
  - Added hca_self_test.ofed installation
* Tue Oct 28 2008 jjolly@suse.de
- Updated to v1.4 from OFED 1.3 rc3
* Mon Oct 27 2008 ro@suse.de
- fix build
* Fri Sep 12 2008 jjolly@suse.de
- Updated to v1.3 from OFED 1.4 RC1
* Tue Aug  7 2007 hvogel@suse.de
- Update to version from OFED 1.2c
* Thu Jul 12 2007 hvogel@suse.de
- package include/mtcr.h
* Wed Jul  4 2007 hvogel@suse.de
- Add GPL COPYING file [#288876]
* Tue Jul  3 2007 hvogel@suse.de
- Use correct git checkout from OFED 1.2
* Wed Jun 20 2007 hvogel@suse.de
- Initial Package, Version 1.2
